@@ -1,11 +1,11 @@
-# @(#)$Id: CPANTesting.pm 151 2012-04-29 10:47:45Z pjf $
+# @(#)$Id: CPANTesting.pm 152 2012-05-02 14:07:33Z pjf $
 
 package CPANTesting;
 
 use strict;
 use warnings;
 
-my $osname = lc $^O; my $uname = qx(uname -a);
+my $osname = lc $^O; my $uname = lc qx(uname -a);
 
 sub broken_toolchain {
    return 0;
@@ -16,7 +16,7 @@ sub exceptions {
    $osname eq q(mirbsd)           and return 'Mirbsd not supported';
    $osname eq q(mswin32)          and return 'Mswin  not supported';
    $osname eq q(netbsd)           and return 'Netbsd not supported';
-   $uname  eq q(k83)              and return 'Stopped andk k83';
+   $uname =~ m{ linux \s+ k83 }mx and return 'Stopped andk k83';
    $uname =~ m{ profvince.com }mx and return 'Stopped vpit';
    return 0;
 }
